SuperMap.Format.GML = SuperMap.Class(SuperMap.Format.XML, {
    featureNS: "http://mapserver.gis.umn.edu/mapserver",
    featurePrefix: "feature",
    featureName: "featureMember",
    layerName: "features",
    geometryName: "geometry",
    collectionName: "FeatureCollection",
    gmlns: "http://www.opengis.net/gml",
    extractAttributes: true,
    extractStyle:true,
    xy: true,
    initialize: function(a) {
        this.regExes = {
            trimSpace: (/^\s*|\s*$/g),
            removeSpace: (/\s*/g),
            splitSpace: (/\s+/),
            trimComma: (/\s*,\s*/g)
        };
        SuperMap.Format.XML.prototype.initialize.apply(this, [a])
    },
    read: function(e) {
        if (typeof e == "string") {
            e = SuperMap.Format.XML.prototype.read.apply(this, [e])
        }
        var f = this.getElementsByTagNameNS(e.documentElement, this.gmlns, this.featureName);
        var d = [];
        for (var c = 0; c < f.length; c++) {
            var a = this.parseFeature(f[c]);
            if (a) {
                d.push(a)
            }
        }
        return d
    },
    parseFeature: function(e) {
        var f = ["MultiPolygon", "Polygon", "MultiLineString", "LineString", "MultiPoint", "Point", "Envelope","GeoCircle","GeoCurveFlag","GeoDiagonalArrow","GeoDoveTailDiagonalArrow","GeoDoubleArrow","GeoRectFlag","GeoStraightArrow","GeoDoveTailStraightArrow","GeoTriangleFlag"];
        var q, j, r, d;
        for (var m = 0; m < f.length; ++m) {
            q = f[m];
            j = this.getElementsByTagNameNS(e, this.gmlns, q);
            if (j.length > 0) {
                d = this.parseGeometry[q.toLowerCase()];
                if (d) {
                    r = d.apply(this, [j[0]]);
                    if (this.internalProjection && this.externalProjection) {
                        r.transform(this.externalProjection, this.internalProjection)
                    }
                } else {
                    throw new TypeError("Unsupported geometry type: " + q)
                }
                break
            }
        }
        var c;
        var l = this.getElementsByTagNameNS(e, this.gmlns, "Box");
        for (m = 0; m < l.length; ++m) {
            var p = l[m];
            var o = this.parseGeometry.box.apply(this, [p]);
            var n = p.parentNode;
            var h = n.localName || n.nodeName.split(":").pop();
            if (h === "boundedBy") {
                c = o
            } else {
                r = o.toGeometry()
            }
        }
        var k,style;
        if (this.extractAttributes) {
            //k = this.parseAttributes(e);
            k = this.parseAttributes2(e);
        }
        if (this.extractStyle) {
            style = this.parseStyle(e);
        }
        var s = new SuperMap.Feature.Vector(r, k,style);
        s.bounds = c;
        s.gml = {
            featureType: e.firstChild.nodeName.split(":")[1],
            featureNS: e.firstChild.namespaceURI,
            featureNSPrefix: e.firstChild.prefix
        };
        var a = e.firstChild;
        var g;
        while (a) {
            if (a.nodeType == 1) {
                g = a.getAttribute("fid") || a.getAttribute("id");
                if (g) {
                    break
                }
            }
            a = a.nextSibling
        }
        s.fid = g;
        return s
    },
    parseGeometry: {
        point: function(e) {
            var c, a;
            var f = [];
            var c = this.getElementsByTagNameNS(e, this.gmlns, "pos");
            if (c.length > 0) {
                a = c[0].firstChild.nodeValue;
                a = a.replace(this.regExes.trimSpace, "");
                f = a.split(this.regExes.splitSpace)
            }
            if (f.length == 0) {
                c = this.getElementsByTagNameNS(e, this.gmlns, "coordinates");
                if (c.length > 0) {
                    a = c[0].firstChild.nodeValue;
                    a = a.replace(this.regExes.removeSpace, "");
                    f = a.split(",")
                }
            }
            if (f.length == 0) {
                c = this.getElementsByTagNameNS(e, this.gmlns, "coord");
                if (c.length > 0) {
                    var g = this.getElementsByTagNameNS(c[0], this.gmlns, "X");
                    var d = this.getElementsByTagNameNS(c[0], this.gmlns, "Y");
                    if (g.length > 0 && d.length > 0) {
                        f = [g[0].firstChild.nodeValue, d[0].firstChild.nodeValue]
                    }
                }
            }
            if (f.length == 2) {
                f[2] = null
            }
            if (this.xy) {
                return new SuperMap.Geometry.Point(f[0], f[1], f[2])
            } else {
                return new SuperMap.Geometry.Point(f[1], f[0], f[2])
            }
        },
        multipoint: function(f) {
            var c = this.getElementsByTagNameNS(f, this.gmlns, "Point");
            var e = [];
            if (c.length > 0) {
                var a;
                for (var d = 0; d < c.length; ++d) {
                    a = this.parseGeometry.point.apply(this, [c[d]]);
                    if (a) {
                        e.push(a)
                    }
                }
            }
            return new SuperMap.Geometry.MultiPoint(e)
        },
        linestring: function(d, f) {
            var e, c;
            var o = [];
            var p = [];
            e = this.getElementsByTagNameNS(d, this.gmlns, "posList");
            if (e.length > 0) {
                c = this.getChildValue(e[0]);
                c = c.replace(this.regExes.trimSpace, "");
                o = c.split(this.regExes.splitSpace);
                var k = parseInt(e[0].getAttribute("dimension"));
                var g, n, m, l;
                for (var h = 0; h < o.length / k; ++h) {
                    g = h * k;
                    n = o[g];
                    m = o[g + 1];
                    l = (k == 2) ? null: o[g + 2];
                    if (this.xy) {
                        p.push(new SuperMap.Geometry.Point(n, m, l))
                    } else {
                        p.push(new SuperMap.Geometry.Point(m, n, l))
                    }
                }
            }
            if (o.length == 0) {
                e = this.getElementsByTagNameNS(d, this.gmlns, "coordinates");
                if (e.length > 0) {
                    c = this.getChildValue(e[0]);
                    c = c.replace(this.regExes.trimSpace, "");
                    c = c.replace(this.regExes.trimComma, ",");
                    var a = c.split(this.regExes.splitSpace);
                    for (var h = 0; h < a.length; ++h) {
                        o = a[h].split(",");
                        if (o.length == 2) {
                            o[2] = null
                        }
                        if (this.xy) {
                            p.push(new SuperMap.Geometry.Point(o[0], o[1], o[2]))
                        } else {
                            p.push(new SuperMap.Geometry.Point(o[1], o[0], o[2]))
                        }
                    }
                }
            }
            var q = null;
            if (p.length != 0) {
                if (f) {
                    q = new SuperMap.Geometry.LinearRing(p)
                } else {
                    q = new SuperMap.Geometry.LineString(p)
                }
            }
            return q
        },
        multilinestring: function(f) {
            var c = this.getElementsByTagNameNS(f, this.gmlns, "LineString");
            var e = [];
            if (c.length > 0) {
                var a;
                for (var d = 0; d < c.length; ++d) {
                    a = this.parseGeometry.linestring.apply(this, [c[d]]);
                    if (a) {
                        e.push(a)
                    }
                }
            }
            return new SuperMap.Geometry.MultiLineString(e)
        },
        polygon: function(f) {
            var c = this.getElementsByTagNameNS(f, this.gmlns, "LinearRing");
            var e = [];
            if (c.length > 0) {
                var a;
                for (var d = 0; d < c.length; ++d) {
                    a = this.parseGeometry.linestring.apply(this, [c[d], true]);
                    if (a) {
                        e.push(a)
                    }
                }
            }
            return new SuperMap.Geometry.Polygon(e)
        },
        multipolygon: function(f) {
            var a = this.getElementsByTagNameNS(f, this.gmlns, "Polygon");
            var e = [];
            if (a.length > 0) {
                var d;
                for (var c = 0; c < a.length; ++c) {
                    d = this.parseGeometry.polygon.apply(this, [a[c]]);
                    if (d) {
                        e.push(d)
                    }
                }
            }
            return new SuperMap.Geometry.MultiPolygon(e)
        },
        envelope: function(c) {
            var f = [];
            var a;
            var g;
            var k = this.getElementsByTagNameNS(c, this.gmlns, "lowerCorner");
            if (k.length > 0) {
                var i = [];
                if (k.length > 0) {
                    a = k[0].firstChild.nodeValue;
                    a = a.replace(this.regExes.trimSpace, "");
                    i = a.split(this.regExes.splitSpace)
                }
                if (i.length == 2) {
                    i[2] = null
                }
                if (this.xy) {
                    var e = new SuperMap.Geometry.Point(i[0], i[1], i[2])
                } else {
                    var e = new SuperMap.Geometry.Point(i[1], i[0], i[2])
                }
            }
            var h = this.getElementsByTagNameNS(c, this.gmlns, "upperCorner");
            if (h.length > 0) {
                var i = [];
                if (h.length > 0) {
                    a = h[0].firstChild.nodeValue;
                    a = a.replace(this.regExes.trimSpace, "");
                    i = a.split(this.regExes.splitSpace)
                }
                if (i.length == 2) {
                    i[2] = null
                }
                if (this.xy) {
                    var j = new SuperMap.Geometry.Point(i[0], i[1], i[2])
                } else {
                    var j = new SuperMap.Geometry.Point(i[1], i[0], i[2])
                }
            }
            if (e && j) {
                f.push(new SuperMap.Geometry.Point(e.x, e.y));
                f.push(new SuperMap.Geometry.Point(j.x, e.y));
                f.push(new SuperMap.Geometry.Point(j.x, j.y));
                f.push(new SuperMap.Geometry.Point(e.x, j.y));
                f.push(new SuperMap.Geometry.Point(e.x, e.y));
                var d = new SuperMap.Geometry.LinearRing(f);
                g = new SuperMap.Geometry.Polygon([d])
            }
            return g
        },
        box: function(f) {
            var d = this.getElementsByTagNameNS(f, this.gmlns, "coordinates");
            var c;
            var g, a = null,
            e = null;
            if (d.length > 0) {
                c = d[0].firstChild.nodeValue;
                g = c.split(" ");
                if (g.length == 2) {
                    a = g[0].split(",");
                    e = g[1].split(",")
                }
            }
            if (a !== null && e !== null) {
                return new SuperMap.Bounds(parseFloat(a[0]), parseFloat(a[1]), parseFloat(e[0]), parseFloat(e[1]))
            }
        },
        controlPoints: function(d,f) {
            var e, c;
            var o = [];
            var p = [];
            if (o.length == 0) {
                e = this.getElementsByTagNameNS(d, this.gmlns, "coordinates");
                if (e.length > 0) {
                    c = this.getChildValue(e[0]);
                    c = c.replace(this.regExes.trimSpace, "");
                    c = c.replace(this.regExes.trimComma, ",");
                    var a = c.split(this.regExes.splitSpace);
                    for (var h = 0; h < a.length; ++h) {
                        o = a[h].split(",");
                        if (o.length == 2) {
                            o[2] = null
                        }
                        if (this.xy) {
                            p.push(new SuperMap.Geometry.Point(o[0], o[1], o[2]))
                        } else {
                            p.push(new SuperMap.Geometry.Point(o[1], o[0], o[2]))
                        }
                    }
                }
            }
            return p
        },
        geocircle: function(f) {
            var c = this.getElementsByTagNameNS(f, this.gmlns, "ControlPoints");
            var e = [];
            if (c.length > 0) {
                var a;
                for (var d = 0; d < c.length; ++d) {
                    a = this.parseGeometry.controlPoints.apply(this, [c[d], true]);
                    if (a) {
                        e = a;
                    }
                }
            }
            return new SuperMap.Geometry.GeoCircle(e)
        },
        geocurveflag: function(f) {
            var c = this.getElementsByTagNameNS(f, this.gmlns, "ControlPoints");
            var e = [];
            if (c.length > 0) {
                var a;
                for (var d = 0; d < c.length; ++d) {
                    a = this.parseGeometry.controlPoints.apply(this, [c[d], true]);
                    if (a) {
                        e = a;
                    }
                }
            }
            return new SuperMap.Geometry.GeoCurveFlag(e)
        },
        geodiagonalarrow: function(f) {
            var c = this.getElementsByTagNameNS(f, this.gmlns, "ControlPoints");
            var e = [];
            if (c.length > 0) {
                var a;
                for (var d = 0; d < c.length; ++d) {
                    a = this.parseGeometry.controlPoints.apply(this, [c[d], true]);
                    if (a) {
                        e = a;
                    }
                }
            }
            return new SuperMap.Geometry.GeoDiagonalArrow(e)
        },
        geodovetaildiagonalarrow: function(f) {
            var c = this.getElementsByTagNameNS(f, this.gmlns, "ControlPoints");
            var e = [];
            if (c.length > 0) {
                var a;
                for (var d = 0; d < c.length; ++d) {
                    a = this.parseGeometry.controlPoints.apply(this, [c[d], true]);
                    if (a) {
                        e = a;
                    }
                }
            }
            return new SuperMap.Geometry.GeoDoveTailDiagonalArrow(e)
        },
        geodoublearrow: function(f) {
            var c = this.getElementsByTagNameNS(f, this.gmlns, "ControlPoints");
            var e = [];
            if (c.length > 0) {
                var a;
                for (var d = 0; d < c.length; ++d) {
                    a = this.parseGeometry.controlPoints.apply(this, [c[d], true]);
                    if (a) {
                        e = a;
                    }
                }
            }
            return new SuperMap.Geometry.GeoDoubleArrow(e)
        },
        georectflag: function(f) {
            var c = this.getElementsByTagNameNS(f, this.gmlns, "ControlPoints");
            var e = [];
            if (c.length > 0) {
                var a;
                for (var d = 0; d < c.length; ++d) {
                    a = this.parseGeometry.controlPoints.apply(this, [c[d], true]);
                    if (a) {
                        e = a;
                    }
                }
            }
            return new SuperMap.Geometry.GeoRectFlag(e)
        },
        geostraightarrow: function(f) {
            var c = this.getElementsByTagNameNS(f, this.gmlns, "ControlPoints");
            var e = [];
            if (c.length > 0) {
                var a;
                for (var d = 0; d < c.length; ++d) {
                    a = this.parseGeometry.controlPoints.apply(this, [c[d], true]);
                    if (a) {
                        e = a;
                    }
                }
            }
            return new SuperMap.Geometry.GeoStraightArrow(e)
        },
        geodovetailstraightarrow: function(f) {
            var c = this.getElementsByTagNameNS(f, this.gmlns, "ControlPoints");
            var e = [];
            if (c.length > 0) {
                var a;
                for (var d = 0; d < c.length; ++d) {
                    a = this.parseGeometry.controlPoints.apply(this, [c[d], true]);
                    if (a) {
                        e = a;
                    }
                }
            }
            return new SuperMap.Geometry.GeoDoveTailStraightArrow(e)
        },
        geotriangleflag: function(f) {
            var c = this.getElementsByTagNameNS(f, this.gmlns, "ControlPoints");
            var e = [];
            if (c.length > 0) {
                var a;
                for (var d = 0; d < c.length; ++d) {
                    a = this.parseGeometry.controlPoints.apply(this, [c[d], true]);
                    if (a) {
                        e = a;
                    }
                }
            }
            return new SuperMap.Geometry.GeoTriangleFlag(e)
        }
    },
    parseAttributes: function(f) {
        var g = {};
        var a = f.firstChild;
        var e, h, d, l, k, c, j;
        while (a) {
            if (a.nodeType == 1) {
                e = a.childNodes;
                for (h = 0; h < e.length; ++h) {
                    d = e[h];
                    if (d.nodeType == 1) {
                        l = d.childNodes;
                        if (l.length == 1) {
                            k = l[0];
                            if (k.nodeType == 3 || k.nodeType == 4) {
                                c = (d.prefix) ? d.nodeName.split(":")[1] : d.nodeName;
                                j = k.nodeValue.replace(this.regExes.trimSpace, "");
                                g[c] = j
                            }
                        } else {
                            g[d.nodeName.split(":").pop()] = null
                        }
                    }
                }
                break
            }
            a = a.nextSibling
        }
        return g
    },
    parseAttributes2: function(f) {
        var c = this.getElementsByTagNameNS(f, this.gmlns, "attributes");
        var g = {};
        if (c.length > 0) {
            a = c[0].firstChild.nodeValue;
            g = JSON.parse(a);
        }
        return g
    },
    parseStyle: function(f) {
        var c = this.getElementsByTagNameNS(f, this.featureNS, "style");
        var g = {};
        if (c.length > 0) {
            a = c[0].firstChild.nodeValue;
            g = JSON.parse(a);
        }
        return g
    },
    write: function(d) {
        if (! (SuperMap.Util.isArray(d))) {
            d = [d]
        }
        var c = this.createElementNS("http://www.opengis.net/wfs", "wfs:" + this.collectionName);
        for (var a = 0; a < d.length; a++) {
            c.appendChild(this.createFeatureXML(d[a]))
        }
        return SuperMap.Format.XML.prototype.write.apply(this, [c])
    },
    createFeatureXML: function(k) {
        var i = k.geometry;
        var f = this.buildGeometryNode(i);
        var j = this.createElementNS(this.featureNS, this.featurePrefix + ":" + this.geometryName);
        j.appendChild(f);
        var a = this.createElementNS(this.gmlns, "gml:" + this.featureName);
        var l = this.createElementNS(this.featureNS, this.featurePrefix + ":" + this.layerName);
        var d = k.fid || k.id;
        l.setAttribute("fid", d);
        l.appendChild(j);
        
        var attributeObj = k.attributes;
        var h = this.buildAttributesNode(attributeObj);
        l.appendChild(h);
        
        var styleObj = k.style;
        var m = this.buildStyleNode(styleObj);
        l.appendChild(m);

        // for (var h in k.attributes) {
            // var g = this.createTextNode(k.attributes[h]);
            // var e = h.substring(h.lastIndexOf(":") + 1);
            // var c = this.createElementNS(this.featureNS, this.featurePrefix + ":" + e);
            // c.appendChild(g);
            // l.appendChild(c)
        // }
        a.appendChild(l);
        return a
    },
    buildGeometryNode: function(e) {
        if (this.externalProjection && this.internalProjection) {
            e = e.clone();
            e.transform(this.internalProjection, this.externalProjection)
        }
        var d = e.CLASS_NAME;
        var c = d.substring(d.lastIndexOf(".") + 1);
        var a = this.buildGeometry[c.toLowerCase()];
        return a.apply(this, [e])
    },
    buildGeometry: {
        point: function(c) {
            var a = this.createElementNS(this.gmlns, "gml:Point");
            a.appendChild(this.buildCoordinatesNode(c));
            return a
        },
        multipoint: function(g) {
            var e = this.createElementNS(this.gmlns, "gml:MultiPoint");
            var d = g.components;
            var c, f;
            for (var a = 0; a < d.length; a++) {
                c = this.createElementNS(this.gmlns, "gml:pointMember");
                f = this.buildGeometry.point.apply(this, [d[a]]);
                c.appendChild(f);
                e.appendChild(c)
            }
            return e
        },
        linestring: function(c) {
            var a = this.createElementNS(this.gmlns, "gml:LineString");
            a.appendChild(this.buildCoordinatesNode(c));
            return a
        },
        multilinestring: function(g) {
            var e = this.createElementNS(this.gmlns, "gml:MultiLineString");
            var a = g.components;
            var d, f;
            for (var c = 0; c < a.length; ++c) {
                d = this.createElementNS(this.gmlns, "gml:lineStringMember");
                f = this.buildGeometry.linestring.apply(this, [a[c]]);
                d.appendChild(f);
                e.appendChild(d)
            }
            return e
        },
        linearring: function(c) {
            var a = this.createElementNS(this.gmlns, "gml:LinearRing");
            a.appendChild(this.buildCoordinatesNode(c));
            return a
        },
        controlPoints: function(c) {
            var a = this.createElementNS(this.gmlns, "gml:ControlPoints");
            a.appendChild(this.buildCoordinatesNode(c));
            return a
        },
        polygon: function(h) {
            var e = this.createElementNS(this.gmlns, "gml:Polygon");
            var g = h.components;
            var d, f, c;
            for (var a = 0; a < g.length; ++a) {
                c = (a == 0) ? "outerBoundaryIs": "innerBoundaryIs";
                d = this.createElementNS(this.gmlns, "gml:" + c);
                f = this.buildGeometry.linearring.apply(this, [g[a]]);
                d.appendChild(f);
                e.appendChild(d)
            }
            return e
        },
        multipolygon: function(g) {
            var e = this.createElementNS(this.gmlns, "gml:MultiPolygon");
            var a = g.components;
            var f, c;
            for (var d = 0; d < a.length; ++d) {
                f = this.createElementNS(this.gmlns, "gml:polygonMember");
                c = this.buildGeometry.polygon.apply(this, [a[d]]);
                f.appendChild(c);
                e.appendChild(f)
            }
            return e
        },
        bounds: function(c) {
            var a = this.createElementNS(this.gmlns, "gml:Box");
            a.appendChild(this.buildCoordinatesNode(c));
            return a
        },
        geocircle: function(h) {
            var e = this.createElementNS(this.gmlns, "gml:GeoCircle");
            var g = [];
            g[0] = {};
            g[0].components = h._controlPoints;
            var d, f;
            for (var a = 0; a < g.length; ++a) {
                f = this.buildGeometry.controlPoints.apply(this, [g[a]]);
                e.appendChild(f)
            }
            return e
        },
        geocurveflag: function(h) {
            var e = this.createElementNS(this.gmlns, "gml:GeoCurveFlag");
            var g = [];
            g[0] = {};
            g[0].components = h._controlPoints;
            var d, f;
            for (var a = 0; a < g.length; ++a) {
                f = this.buildGeometry.controlPoints.apply(this, [g[a]]);
                e.appendChild(f)
            }
            return e
        },
        geodiagonalarrow: function(h) {
            var e = this.createElementNS(this.gmlns, "gml:GeoDiagonalArrow");
            var g = [];
            g[0] = {};
            g[0].components = h._controlPoints;
            var d, f;
            for (var a = 0; a < g.length; ++a) {
                f = this.buildGeometry.controlPoints.apply(this, [g[a]]);
                e.appendChild(f)
            }
            return e
        },
        geodovetaildiagonalarrow: function(h) {
            var e = this.createElementNS(this.gmlns, "gml:GeoDoveTailDiagonalArrow");
            var g = [];
            g[0] = {};
            g[0].components = h._controlPoints;
            var d, f;
            for (var a = 0; a < g.length; ++a) {
                f = this.buildGeometry.controlPoints.apply(this, [g[a]]);
                e.appendChild(f)
            }
            return e
        },
        geodoublearrow: function(h) {
            var e = this.createElementNS(this.gmlns, "gml:GeoDoubleArrow");
            var g = [];
            g[0] = {};
            g[0].components = h._controlPoints;
            var d, f;
            for (var a = 0; a < g.length; ++a) {
                f = this.buildGeometry.controlPoints.apply(this, [g[a]]);
                e.appendChild(f)
            }
            return e
        },
        georectflag: function(h) {
            var e = this.createElementNS(this.gmlns, "gml:GeoRectFlag");
            var g = [];
            g[0] = {};
            g[0].components = h._controlPoints;
            var d, f;
            for (var a = 0; a < g.length; ++a) {
                f = this.buildGeometry.controlPoints.apply(this, [g[a]]);
                e.appendChild(f)
            }
            return e
        },
        geostraightarrow: function(h) {
            var e = this.createElementNS(this.gmlns, "gml:GeoStraightArrow");
            var g = [];
            g[0] = {};
            g[0].components = h._controlPoints;
            var d, f;
            for (var a = 0; a < g.length; ++a) {
                f = this.buildGeometry.controlPoints.apply(this, [g[a]]);
                e.appendChild(f)
            }
            return e
        },
        geodovetailstraightarrow: function(h) {
            var e = this.createElementNS(this.gmlns, "gml:GeoDoveTailStraightArrow");
            var g = [];
            g[0] = {};
            g[0].components = h._controlPoints;
            var d, f;
            for (var a = 0; a < g.length; ++a) {
                f = this.buildGeometry.controlPoints.apply(this, [g[a]]);
                e.appendChild(f)
            }
            return e
        },
        geotriangleflag: function(h) {
            var e = this.createElementNS(this.gmlns, "gml:GeoTriangleFlag");
            var g = [];
            g[0] = {};
            g[0].components = h._controlPoints;
            var d, f;
            for (var a = 0; a < g.length; ++a) {
                f = this.buildGeometry.controlPoints.apply(this, [g[a]]);
                e.appendChild(f)
            }
            return e
        }
    },
    buildCoordinatesNode: function(g) {
        var a = this.createElementNS(this.gmlns, "gml:coordinates");
        a.setAttribute("decimal", ".");
        a.setAttribute("cs", ",");
        a.setAttribute("ts", " ");
        var f = [];
        if (g instanceof SuperMap.Bounds) {
            f.push(g.left + "," + g.bottom);
            f.push(g.right + "," + g.top)
        } else {
            var d = (g.components) ? g.components: [g];
            for (var c = 0; c < d.length; c++) {
                f.push(d[c].x + "," + d[c].y)
            }
        }
        var e = this.createTextNode(f.join(" "));
        a.appendChild(e);
        return a
    },
    buildAttributesNode: function(obj) {
        var a = this.createElementNS(this.featureNS, "feature:attributes");
        var jsonStr = JSON.stringify(obj);
        var j = this.createTextNode(jsonStr);
        a.appendChild(j);
        return a
    },
    buildStyleNode: function(obj) {
        var a = this.createElementNS(this.featureNS, "feature:style");
        var jsonStr = JSON.stringify(obj);
        var j = this.createTextNode(jsonStr);
        a.appendChild(j);
        return a
    },
    CLASS_NAME: "SuperMap.Format.GML"
});